@@ -15,9 +15,9 @@
        under the License.
 */
 'use strict';
-const fs = require('fs-extra');
-const path = require('path');
-const util = require('util');
+const fs = require('node:fs');
+const path = require('node:path');
+const util = require('node:util');
 const events = require('cordova-common').events;
 const CordovaError = require('cordova-common').CordovaError;
 
@@ -76,7 +76,7 @@ const handlers = {
             const destFile = path.resolve(project.resources_dir, target);
 
             project.xcode.removeResourceFile(path.join('Resources', target));
-            fs.removeSync(destFile);
+            fs.rmSync(destFile, { recursive: true, force: true });
         }
     },
     framework: { // CB-5238 custom frameworks only
@@ -154,7 +154,7 @@ const handlers = {
             if (pbxFile) {
                 project.xcode.removeFromPbxEmbedFrameworksBuildPhase(pbxFile);
             }
-            fs.removeSync(targetDir);
+            fs.rmSync(targetDir, { recursive: true, force: true });
         }
     },
     'lib-file': {
@@ -206,11 +206,11 @@ const handlers = {
             scriptContent = `cordova.define("${moduleName}", function(require, exports, module) {\n${scriptContent}\n});\n`;
 
             const moduleDestination = path.resolve(project.www, 'plugins', plugin.id, obj.src);
-            fs.ensureDirSync(path.dirname(moduleDestination));
+            fs.mkdirSync(path.dirname(moduleDestination), { recursive: true });
             fs.writeFileSync(moduleDestination, scriptContent, 'utf-8');
             if (options && options.usePlatformWww) {
                 const platformWwwDestination = path.resolve(project.platformWww, 'plugins', plugin.id, obj.src);
-                fs.ensureDirSync(path.dirname(platformWwwDestination));
+                fs.mkdirSync(path.dirname(platformWwwDestination), { recursive: true });
                 fs.writeFileSync(platformWwwDestination, scriptContent, 'utf-8');
             }
         },
@@ -292,7 +292,7 @@ function uninstallHelper (type, obj, project_dir, plugin_id, options, project) {
         project_ref = `Plugins/${fixPathSep(path.relative(project.plugins_dir, destFile))}`;
     }
 
-    fs.removeSync(targetDir);
+    fs.rmSync(targetDir, { recursive: true, force: true });
 
     if (type === 'header-file') {
         project.xcode.removeHeaderFile(project_ref);
@@ -324,12 +324,12 @@ function copyFile (plugin_dir, src, project_dir, dest, link) {
     // check that dest path is located in project directory
     if (dest.indexOf(project_dir) !== 0) { throw new CordovaError(`Destination "${dest}" for source file "${src}" is located outside the project`); }
 
-    fs.ensureDirSync(path.dirname(dest));
+    fs.mkdirSync(path.dirname(dest), { recursive: true });
 
     if (link) {
         linkFileOrDirTree(src, dest);
     } else {
-        fs.copySync(src, dest);
+        fs.cpSync(src, dest, { recursive: true });
     }
 }
 
@@ -343,11 +343,11 @@ function copyNewFile (plugin_dir, src, project_dir, dest, link) {
 
 function linkFileOrDirTree (src, dest) {
     if (fs.existsSync(dest)) {
-        fs.removeSync(dest);
+        fs.rmSync(dest, { recursive: true, force: true });
     }
 
     if (fs.statSync(src).isDirectory()) {
-        fs.ensureDirSync(dest);
+        fs.mkdirSync(dest, { recursive: true });
         fs.readdirSync(src).forEach(entry => {
             linkFileOrDirTree(path.join(src, entry), path.join(dest, entry));
         });
@@ -359,12 +359,12 @@ function linkFileOrDirTree (src, dest) {
 // checks if file exists and then deletes. Error if doesn't exist
 function removeFile (project_dir, src) {
     const file = path.resolve(project_dir, src);
-    fs.removeSync(file);
+    fs.rmSync(file);
 }
 
 // deletes file/directory without checking
 function removeFileF (file) {
-    fs.removeSync(file);
+    fs.rmSync(file);
 }
 
 function removeFileAndParents (baseDir, destFile, stopper) {
