@@ -17,13 +17,10 @@
     under the License.
 */
 
-'use strict';
-
-const fs = require('fs-extra');
-const path = require('path');
-const unorm = require('unorm');
+const fs = require('node:fs');
+const path = require('node:path');
 const plist = require('plist');
-const URL = require('url');
+const et = require('elementtree');
 const events = require('cordova-common').events;
 const xmlHelpers = require('cordova-common').xmlHelpers;
 const ConfigParser = require('cordova-common').ConfigParser;
@@ -35,6 +32,7 @@ const FileUpdater = require('cordova-common').FileUpdater;
 const projectFile = require('./projectFile');
 const Podfile = require('./Podfile').Podfile;
 const check_reqs = require('./check_reqs');
+const PlatformConfigParser = require('./PlatformConfigParser');
 
 // launch storyboard and related constants
 const IMAGESET_COMPACT_SIZE_CLASS = 'compact';
@@ -43,9 +41,16 @@ const CDV_ANY_SIZE_CLASS = 'any';
 module.exports.prepare = function (cordovaProject, options) {
     const platformJson = PlatformJson.load(this.locations.root, 'ios');
     const munger = new PlatformMunger('ios', this.locations.root, platformJson, new PluginInfoProvider());
-
     this._config = updateConfigFile(cordovaProject.projectConfig, munger, this.locations);
 
+    const parser = new PlatformConfigParser(cordovaProject.projectConfig.path);
+    try {
+        const manifest = parser.getPrivacyManifest();
+        overwritePrivacyManifest(manifest, this.locations);
+    } catch (err) {
+        return Promise.reject(new CordovaError(`Could not parse PrivacyManifest in config.xml: ${err}`));
+    }
+
     // Update own www dir with project's www assets and plugins' assets and js-files
     return updateWww(cordovaProject, this.locations)
         // update project according to config.xml changes.
@@ -87,6 +92,33 @@ module.exports.clean = function (options) {
     });
 };
 
+/**
+ * Overwrites the privacy manifest file with the provided manifest or sets the default manifest.
+ * @param {ElementTree} manifest - The manifest to be written to the privacy manifest file.
+ * @param {Object} locations - The locations object containing the path to the Xcode Cordova project.
+ */
+function overwritePrivacyManifest (manifest, locations) {
+    const privacyManifestDest = path.join(locations.xcodeCordovaProj, 'PrivacyInfo.xcprivacy');
+    if (manifest != null) {
+        const XML_DECLARATION = '<?xml version="1.0" encoding="UTF-8"?>\n';
+        const DOCTYPE = '<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">\n';
+        const plistElement = et.Element('plist');
+        plistElement.set('version', '1.0');
+        const dictElement = et.SubElement(plistElement, 'dict');
+        manifest.getchildren().forEach((child) => {
+            dictElement.append(child);
+        });
+        const etree = new et.ElementTree(plistElement);
+        const xmlString = XML_DECLARATION + DOCTYPE + etree.write({ xml_declaration: false });
+        fs.writeFileSync(privacyManifestDest, xmlString, 'utf-8');
+        return;
+    }
+    // Set default privacy manifest
+    const defaultPrivacyManifest = path.join(__dirname, '..', 'templates', 'project', '__PROJECT_NAME__', 'PrivacyInfo.xcprivacy');
+    const xmlString = fs.readFileSync(defaultPrivacyManifest, 'utf8');
+    fs.writeFileSync(privacyManifestDest, xmlString, 'utf-8');
+}
+
 /**
  * Updates config files in project based on app's config.xml and config munge,
  *   generated by plugins.
@@ -106,7 +138,7 @@ function updateConfigFile (sourceConfig, configMunger, locations) {
 
     // First cleanup current config and merge project's one into own
     // Overwrite platform config.xml with defaults.xml.
-    fs.copySync(locations.defaultConfigXml, locations.configXml);
+    fs.cpSync(locations.defaultConfigXml, locations.configXml);
 
     // Then apply config changes from global munge to all config files
     // in project (including project's config)
@@ -183,7 +215,7 @@ function updateProject (platformConfig, locations) {
     // CB-6992 it is necessary to normalize characters
     // because node and shell scripts handles unicode symbols differently
     // We need to normalize the name to NFD form since iOS uses NFD unicode form
-    const name = unorm.nfd(platformConfig.name());
+    const name = platformConfig.name().normalize('NFD');
     const version = platformConfig.version();
     const displayName = platformConfig.shortName && platformConfig.shortName();
 
@@ -374,12 +406,12 @@ function mapIconResources (icons, iconsDir) {
 
 function getIconsDir (projectRoot, platformProjDir) {
     let iconsDir;
-    const xcassetsExists = folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets/'));
+    const xcassetsExists = folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets'));
 
     if (xcassetsExists) {
-        iconsDir = path.join(platformProjDir, 'Assets.xcassets/AppIcon.appiconset/');
+        iconsDir = path.join(platformProjDir, 'Assets.xcassets', 'AppIcon.appiconset');
     } else {
-        iconsDir = path.join(platformProjDir, 'Resources/icons/');
+        iconsDir = path.join(platformProjDir, 'Resources', 'icons');
     }
 
     return iconsDir;
@@ -426,13 +458,28 @@ function cleanIcons (projectRoot, projectConfig, locations) {
  * @param  {string} platformProjDir    The platform's project directory
  */
 function getBackgroundColorDir (projectRoot, platformProjDir) {
-    if (folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets/'))) {
+    if (folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets'))) {
         return path.join(platformProjDir, 'Assets.xcassets', 'BackgroundColor.colorset');
     } else {
         return null;
     }
 }
 
+/**
+ * Returns the directory for the SplashScreenBackgroundColor.colorset asset, or
+ * null if no xcassets exist.
+ *
+ * @param  {string} projectRoot        The project's root directory
+ * @param  {string} platformProjDir    The platform's project directory
+ */
+function getSplashScreenBackgroundColorDir (projectRoot, platformProjDir) {
+    if (folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets/'))) {
+        return path.join(platformProjDir, 'Assets.xcassets', 'SplashScreenBackgroundColor.colorset');
+    } else {
+        return null;
+    }
+}
+
 function colorPreferenceToComponents (pref) {
     if (!pref || !pref.match(/^(#[0-9A-Fa-f]{3}|(0x|#)([0-9A-Fa-f]{2})?[0-9A-Fa-f]{6})$/)) {
         return {
@@ -483,11 +530,12 @@ function colorPreferenceToComponents (pref) {
  * @param {Object} locations A dictionary containing useful location paths
  */
 function updateBackgroundColor (cordovaProject, locations) {
-    const pref = cordovaProject.projectConfig.getPreference('BackgroundColor', 'ios') || '';
-
     const platformProjDir = path.relative(cordovaProject.root, locations.xcodeCordovaProj);
-    const backgroundColorDir = getBackgroundColorDir(cordovaProject.root, platformProjDir);
 
+    const pref = cordovaProject.projectConfig.getPreference('BackgroundColor', 'ios') || '';
+    const splashPref = cordovaProject.projectConfig.getPreference('SplashScreenBackgroundColor', 'ios') || pref;
+
+    const backgroundColorDir = getBackgroundColorDir(cordovaProject.root, platformProjDir);
     if (backgroundColorDir) {
         const contentsJSON = {
             colors: [{
@@ -504,6 +552,24 @@ function updateBackgroundColor (cordovaProject, locations) {
         fs.writeFileSync(path.join(cordovaProject.root, backgroundColorDir, 'Contents.json'),
             JSON.stringify(contentsJSON, null, 2));
     }
+
+    const splashBackgroundColorDir = getSplashScreenBackgroundColorDir(cordovaProject.root, platformProjDir);
+    if (splashBackgroundColorDir) {
+        const contentsJSON = {
+            colors: [{
+                idiom: 'universal',
+                color: colorPreferenceToComponents(splashPref)
+            }],
+            info: {
+                author: 'Xcode',
+                version: 1
+            }
+        };
+
+        events.emit('verbose', 'Updating Splash Screen Background Color color set Contents.json');
+        fs.writeFileSync(path.join(cordovaProject.root, splashBackgroundColorDir, 'Contents.json'),
+            JSON.stringify(contentsJSON, null, 2));
+    }
 }
 
 /**
@@ -515,24 +581,31 @@ function updateBackgroundColor (cordovaProject, locations) {
  */
 function cleanBackgroundColor (projectRoot, projectConfig, locations) {
     const platformProjDir = path.relative(projectRoot, locations.xcodeCordovaProj);
+
+    const contentsJSON = {
+        colors: [{
+            idiom: 'universal',
+            color: colorPreferenceToComponents(null)
+        }],
+        info: {
+            author: 'Xcode',
+            version: 1
+        }
+    };
+
     const backgroundColorDir = getBackgroundColorDir(projectRoot, platformProjDir);
-
     if (backgroundColorDir) {
-        const contentsJSON = {
-            colors: [{
-                idiom: 'universal',
-                color: colorPreferenceToComponents(null)
-            }],
-            info: {
-                author: 'Xcode',
-                version: 1
-            }
-        };
-
         events.emit('verbose', 'Cleaning Background Color color set Contents.json');
         fs.writeFileSync(path.join(projectRoot, backgroundColorDir, 'Contents.json'),
             JSON.stringify(contentsJSON, null, 2));
     }
+
+    const splashBackgroundColorDir = getSplashScreenBackgroundColorDir(projectRoot, platformProjDir);
+    if (splashBackgroundColorDir) {
+        events.emit('verbose', 'Cleaning Splash Screen Background Color color set Contents.json');
+        fs.writeFileSync(path.join(projectRoot, splashBackgroundColorDir, 'Contents.json'),
+            JSON.stringify(contentsJSON, null, 2));
+    }
 }
 
 function updateFileResources (cordovaProject, locations) {
@@ -831,10 +904,10 @@ function getLaunchStoryboardContentsJSON (splashScreens, launchStoryboardImagesD
  */
 function getLaunchStoryboardImagesDir (projectRoot, platformProjDir) {
     let launchStoryboardImagesDir;
-    const xcassetsExists = folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets/'));
+    const xcassetsExists = folderExists(path.join(projectRoot, platformProjDir, 'Assets.xcassets'));
 
     if (xcassetsExists) {
-        launchStoryboardImagesDir = path.join(platformProjDir, 'Assets.xcassets/LaunchStoryboard.imageset/');
+        launchStoryboardImagesDir = path.join(platformProjDir, 'Assets.xcassets', 'LaunchStoryboard.imageset');
     } else {
         // if we don't have a asset library for images, we can't do the storyboard.
         launchStoryboardImagesDir = null;
@@ -1042,13 +1115,13 @@ function parseAllowlistUrlForATS (url, options) {
 
     let href = null;
     try {
-        href = new URL.URL(url);
+        href = new URL(url);
     } catch (e) {
         const scheme = url.split(':')[0];
         // If there's a wildcard in the protocol, the URL will fail to parse
         // Replace it with "http" to allow insecure loads
         if (scheme.includes('*')) {
-            href = new URL.URL(url.replace(scheme, 'http'));
+            href = new URL(url.replace(scheme, 'http'));
         } else {
             return null;
         }
